@@ -10,6 +10,11 @@ int main(int argc, char *argv[])
     // Simple loader for loading QML files
     QmlLoader loader;
     loader.resize(800,480);
-    loader.show();
+#ifdef Q_WS_MAC
+        loader.show();
+#else
+        loader.showFullScreen();
+#endif
+    
     return a.exec();
 }
